Compute quantiles for the covariance matrix per cluster based on the MCMC output stored in a fabMix.object.
CovMat_mcmc_summary(x, quantile_probs)A list containing the quantiles for the covariance matrix per component. Each element is a \(p\times p \times K\) array, where \(p\) and \(K\) denote the dimension of the multivariate data and number of alive components for the selected model, respectively.
An object of class fabMix.object.
Vector of probabilities for computing the corresponding quantiles.
Panagiotis Papastamoulis